Learn R Programming

lmomco (version 2.2.4)

USGSsta06766000dvs: Daily Mean Streamflow Data for U.S. Geological Survey Streamflow-Gaging Station 06766000

Description

Daily mean streamflow data for U.S. Geological Survey streamflow-gaging station 06766000 PLATTE RIVER AT BRADY, NE. The qualification code X01_00060_00003_cd values are:
A
Approved for publication --- Processing and review completed.

1
Daily value is write protected without any remark code to be printed.

Usage

data(USGSsta06766000dvs)

Arguments

Format

An R data.frame with
agency_cd
The agency code USGS.
site_no
The station identification number.
datetime
The date and time of the data.
X01_00060_00003
The daily mean streamflow data in cubic feet per second.
X01_00060_00003_cd
A code on the data value.

Examples

Run this code
data(USGSsta06766000dvs)
## Not run: plot(USGSsta06766000dvs)

Run the code above in your browser using DataLab