Learn R Programming

lmomco (version 2.2.4)

USGSsta08167000peaks: Annual Peak Streamflow Data for U.S. Geological Survey Streamflow-Gaging Station 08167000

Description

Annual peak streamflow data for U.S. Geological Survey streamflow-gaging station 08167000. The peak streamflow-qualification codes Flag are:
1
Discharge is a Maximum Daily Average

2
Discharge is an Estimate

3
Discharge affected by Dam Failure

4
Discharge less than indicated value, which is Minimum Recordable Discharge at this site

5
Discharge affected to unknown degree by Regulation or Diversion

6
Discharge affected by Regulation or Diversion

7
Discharge is an Historic Peak

8
Discharge actually greater than indicated value

9
Discharge due to Snowmelt, Hurricane, Ice-Jam or Debris Dam breakup

A
Year of occurrence is unknown or not exact

B
Month or Day of occurrence is unknown or not exact

C
All or part of the record affected by Urbanization, Mining, Agricultural changes, Channelization, or other

D
Base Discharge changed during this year

E
Only Annual Maximum Peak available for this year

The gage height qualification codes Flag.1 are:

1
Gage height affected by backwater

2
Gage height not the maximum for the year

3
Gage height at different site and(or) datum

4
Gage height below minimum recordable elevation

5
Gage height is an estimate

6
Gage datum changed during this year

Usage

data(USGSsta08167000peaks)

Arguments

Format

An R data.frame with
agency_cd
Agency code.
site_no
Agency station number.
peak_dt
The date of the annual peak streamflow.
peak_tm
Time of the peak streamflow.
peak_va
Annual peak streamflow data in cubic feet per second.
peak_cd
Qualification flags on the streamflow data.
gage_ht
Annual peak stage (gage height, river height) in feet.
gage_ht_cd
Qualification flags on the gage height data.
year_last_pk
Peak streamflow reported is the highest since this year.
ag_dt
Date of maximum gage-height for water year (if not concurrent with peak).
ag_tm
Time of maximum gage-height for water year (if not concurrent with peak).
ag_gage_ht
Maximum gage height for water year in feet (if not concurrent with peak).
ag_gage_ht_cd
Maximum gage height code.

Examples

Run this code
data(USGSsta08167000peaks)
## Not run: plot(USGSsta08167000peaks)

Run the code above in your browser using DataLab