Is the distribution parameter object consistent with the corresponding distribution? The distribution functions (cdfemu, pdfemu, quaemu, lmomemu), and lmomemu require consistent parameters to return the cumulative probability (nonexceedance), density, quantile, and L-moments of the distribution, respectively. These functions internally use the are.paremu.valid function. The documentation for pdfemu provides the conditions for valid parameters.
are.paremu.valid(para, nowarn=FALSE)
If the parameters are emu consistent.
If the parameters are not emu consistent.
A distribution parameter list returned by paremu or vec2par.
A logical switch on warning suppression. If TRUE then options(warn=-1) is made and restored on return. This switch is to permit calls in which warnings are not desired as the user knows how to handle the returned value---say in an optimization algorithm.
W.H. Asquith
is.emu, paremu