partexp are consistent with the corresponding distribution, otherwise a list would not have been returned. However, other functions (cdftexp, quatexp, and lmomtexp require consistent parameters to return the cumulative probability (nonexceedance), quantile, and L-moments of the distribution, respectively.are.partexp.valid(para, nowarn=FALSE)parexp.TRUE then options(warn=-1) is made and restored on return. This switch is to permit calls in which warnings are not desired as the user knows how to handle the returned value---say in atexp consistent.texp consistent.is.texp