Learn R Programming

lmomco (version 2.2.4)

cdf2lmoms: Compute L-moments from Cumulative Distribution Function

Description

Compute the L-moments from a cumulative distribution function. For $r \ge 1$, the L-moments can be computed by sequential calling of cdf2lmom. Consult the documentation of that function for mathematical definitions.

Usage

cdf2lmoms(para, nmom=6, fdepth=0, silent=TRUE, lambegr=1, ...)

Arguments

para
The parameters from lmom2par or similar.
nmom
The number of moments to compute. Default is 6.
fdepth
The depth of the nonexceedance/exceedance probabilities to determine the lower and upper integration limits through a call to the par2qua function. The default of 0 implies the quantile for $F=0$ and quantile for $F=1$ as the respective lower and upper limits.
silent
A logical to be passed into cdf2lmom and then onto the try functions encompassing the integrate function calls.
lambegr
The $r$th order to begin the sequence for L-moment computation. Can be used as a means to bypass a mean computation if the user has an alternative method for the mean or other central tendency characterization in which case lambegr = 2.
...
Additional arguments to pass to cdf2lmom.

Value

An R list is returned.
lambdas
Vector of the L-moments. First element is $\hat{\lambda}^{(0,0)}_1$, second element is $\hat{\lambda}^{(0,0)}_2$, and so on.
ratios
Vector of the L-moment ratios. Second element is $\hat{\tau}^{(0,0)}$, third element is $\hat{\tau}^{(0,0)}_3$ and so on.
trim
Level of symmetrical trimming used in the computation, which will equal NULL is not support for trimming is provided by this function.
leftrim
Level of left-tail trimming used in the computation, which will equal NULL is not support for trimming is provided by this function.
rightrim
Level of right-tail trimming used in the computation, which will equal NULL is not support for trimming is provided by this function.
source
An attribute identifying the computational source of the L-moments: “cdf2lmoms”.

See Also

cdf2lmom, lmoms

Examples

Run this code
cdf2lmoms(vec2par(c(10,40), type="ray"))
## Not run: 
# # relatively slow computation
# vec2par(c(.9,.4), type="emu"); cdf2lmoms(para, nmom=4)
# vec2par(c(.9,.4), type="emu"); cdf2lmoms(para, nmom=4, fdepth=0)## End(Not run)

Run the code above in your browser using DataLab