quaCCC functions that compute frequency curves for the L-moments. The term frequency curves is common in hydrology and is a renaming of the more widenly known by statisticians term the quantile function. The notation CCC represents the character notation for the distribution: exp, gam, gev, gld, glo, gno, gpa, gum, kap, nor, pe3, wak, and wei. The nonexceedance probabilities to construct the curves are derived from nonexceeds.
freq.curve.all(lmom, aslog10=FALSE, asprob=TRUE, no2para=FALSE, no3para=FALSE, no4para=FALSE, no5para=FALSE, step=FALSE, show=FALSE, xmin=NULL, xmax=NULL, xlim=NULL, ymin=NULL, ymax=NULL, ylim=NULL, aep4=FALSE, exp=TRUE, gam=TRUE, gev=TRUE, gld=FALSE, glo=TRUE, gno=TRUE, gpa=TRUE, gum=TRUE, kap=TRUE, nor=TRUE, pe3=TRUE, wak=TRUE, wei=TRUE,...)log10 of quantiles---note that NaNs produced in: log(x, base)will be produced for less than zero values.
qnorm function is used to convert nonexceedance probabilities, which are produced by nonexceeds, to standard normal variates. The Normal distribution will plot as straight line when this argument is TRUETRUE, do not run the 2-parameter distributions: exp, gam, gum, and nor.TRUE, do not run the 3-parameter distributions: gev, glo, gno, gpa, pe3, and wei.TRUE, do not run the 4-parameter distributions: kap, gld, aep4.TRUE, do not run the 5-parameter distributions: wak.plot.show=TRUE.show=TRUE.show=TRUE.show=TRUE.show=TRUE.show=TRUE.FALSE.TRUE.TRUE.TRUE.FALSE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.parexp.data.frame of frequency curves. The nonexceedance probability values, which are provided by nonexceeds, are the first item in the data.frame under the heading of nonexceeds. If a particular distribution could not be fit to the L-moments of the data; this particular function returns zeros.
quaaep4,
quaexp,
quagam,
quagev,
quagld,
quaglo,
quagno,
quagpa,
quagum,
quakap,
quanor,
quape3,
quawak, and
quawei.
L <- vec2lmom(c(35612,23593,0.48,0.21,0.11))
Qtable1 <- freq.curve.all(L, step=TRUE, no2para=TRUE, no4para=TRUE)
## Not run:
# Qtable2 <- freq.curve.all(L, gld=TRUE, show=TRUE)## End(Not run)
Run the code above in your browser using DataLab