Learn R Programming

lmomco (version 2.2.4)

lmom2par: Convert L-moments to the Parameters of a Distribution

Description

This function converts L-moments to the parameters of a distribution. The type of distribution is specified in the argument list: aep4, cau, emu, exp, gam, gep, gev, gld, glo, gno, gov, gpa, gum, kap, kmu, kur, lap, lmrq, ln3, nor, pe3, ray, revgum, rice, sla, st3, texp, wak, or wei.

Usage

lmom2par(lmom, type, ...)

Arguments

lmom
An L-moment object such as that returned by lmoms or pwm2lmom.
type
Three character (minimum) distribution type (for example, type="gev").
...
Additional arguments for the parCCC functions.

Value

An R list is returned. This list should contain at least the following items, but some distributions such as the revgum have extra.
type
The type of distribution in three character (minimum) format.
para
The parameters of the distribution.
source
Attribute specifying source of the parameters.

See Also

par2lmom

Examples

Run this code
lmr  <- lmoms(rnorm(20))
para <- lmom2par(lmr,type='nor')

# The lmom2par() calls will error if trim != 1.
X <- rcauchy(20)
cauchy <- lmom2par(TLmoms(X, trim=1), type="cau")
slash  <- lmom2par(TLmoms(X, trim=1), type="sla")
## Not run: 
# plot(pp(X), sort(X), xlab="PROBABILITY", ylab="CAUCHY")
# lines(nonexceeds(), par2qua(nonexceeds(), cauchy))
# lines(nonexceeds(), par2qua(nonexceeds(), slash), col=2)
# ## End(Not run)

Run the code above in your browser using DataLab