Show the Errata file for the following book
Asquith, W.H., 2011, Distributional analysis with L-moment statistics using the R environment for statistical computing: Createspace Independent Publishing Platform, ISBN 978--146350841--8.
Available at http://www.amazon.com and search for 1463508417 (their id number) or the ISBN 9781463508418 (do not use hyphens).
The Errata file is named ERRATA_FOR_ISBN9781463508418.txt and is available within the lmomco package in the inst/ directory.
lmomcoBook()None.