parexp. The L-moments in terms of the parameters are $\lambda_1 = \xi + \alpha$, $\lambda_2 = \alpha/2$, $\tau_3 = 1/3$, $\tau_4 = 1/6$, and $\tau_5 = 1/10$.
lmomexp(para)list is returned.0.NULL.NULL.Hosking, J.R.M., 1990, L-moments---Analysis and estimation of distributions using linear combinations of order statistics: Journal of the Royal Statistical Society, Series B, v. 52, pp. 105--124.
Hosking, J.R.M., 1996, FORTRAN routines for use with the method of L-moments: Version 3, IBM Research Report RC20525, T.J. Watson Research Center, Yorktown Heights, New York.
Hosking, J.R.M., and Wallis, J.R., 1997, Regional frequency analysis---An approach based on L-moments: Cambridge University Press.
parexp, cdfexp, pdfexp, quaexp lmr <- lmoms(c(123,34,4,654,37,78))
lmr
lmomexp(parexp(lmr))
Run the code above in your browser using DataLab