TLmoms. The formula jointly handles sample L-moment computation and sample TL-moment (Elamir and Seheult, 2003) computation. A description of the most common L-moments is provided under lmom.ub.
lmoms(x, nmom=5, no.stop=FALSE)NULL instead of issuing a stop() if nmom is greater than the sample size or if all the values are equal. This is a very late change (decade+) to the foundational function in the package. Auxiliary coding to above this function to avoid the internal stop() became non-ignorable in large data mining exercises. It was a design mistake to have the stop() and not a warning() instead.list is returned.Elamir, E.A.H., and Seheult, A.H., 2003, Trimmed L-moments: Computational statistics and data analysis, vol. 43, pp. 299-314.
Hosking, J.R.M., 1990, L-moments---Analysis and estimation of distributions using linear combinations of order statistics: Journal of the Royal Statistical Society, Series B, v. 52, pp. 105--124.
lmom.ub, TLmoms, lmorph, lmoms.bernstein