Learn R Programming

lmomco (version 2.2.4)

lmomwak: L-moments of the Wakeby Distribution

Description

This function estimates the L-moments of the Wakeby distribution given the parameters ($\xi$, $\alpha$, $\beta$, $\gamma$, and $\delta$) from parwak. The L-moments in terms of the parameters are complicated and solved numerically.

Usage

lmomwak(wakpara)

Arguments

wakpara
The parameters of the distribution.

Value

An R list is returned.
lambdas
Vector of the L-moments. First element is $\lambda_1$, second element is $\lambda_2$, and so on.
ratios
Vector of the L-moment ratios. Second element is $\tau$, third element is $\tau_3$ and so on.
trim
Level of symmetrical trimming used in the computation, which is 0.
leftrim
Level of left-tail trimming used in the computation, which is NULL.
rightrim
Level of right-tail trimming used in the computation, which is NULL.
source
An attribute identifying the computational source of the L-moments: “lmomwak”.

References

Hosking, J.R.M., 1990, L-moments---Analysis and estimation of distributions using linear combinations of order statistics: Journal of the Royal Statistical Society, Series B, v. 52, pp. 105--124.

Hosking, J.R.M., 1996, FORTRAN routines for use with the method of L-moments: Version 3, IBM Research Report RC20525, T.J. Watson Research Center, Yorktown Heights, New York.

Hosking, J.R.M., and Wallis, J.R., 1997, Regional frequency analysis---An approach based on L-moments: Cambridge University Press.

See Also

parwak, cdfwak, pdfwak, quawak

Examples

Run this code
lmr <- lmoms(c(123,34,4,654,37,78))
lmr
lmomwak(parwak(lmr))

Run the code above in your browser using DataLab