Learn R Programming

lmomco (version 2.2.4)

lmrdia: L-moment Ratio Diagram Components

Description

This function returns a list of the L-skew and L-kurtosis ($\tau_3$ and $\tau_4$, respectively) ordinates for construction of L-moment Ratio (L-moment diagrams) that are useful in selecting a distribution to model the data.

Usage

lmrdia()

Arguments

Value

An R list is returned.
limits
The theoretical limits of $\tau_3$ and $\tau_4$; below $\tau_4$ of the theoretical limits are theoretically not possible.
aep4
$\tau_3$ and $\tau_4$ lower limits of the Asymmetric Exponential Power distribution.
cau
$\tau^{(1)}_3$ and $\tau^{(1)}_4$ of the Cauchy distribution (TL-moment [trim=1]).
exp
$\tau_3$ and $\tau_4$ of the Exponential distribution.
gev
$\tau_3$ and $\tau_4$ of the Generalized Extreme Value distribution.
glo
$\tau_3$ and $\tau_4$ of the Generalized Logistic distribution.
gpa
$\tau_3$ and $\tau_4$ of the Generalized Pareto distribution.
gum
$\tau_3$ and $\tau_4$ of the Gumbel distribution.
gno
$\tau_3$ and $\tau_4$ of the Generalized Normal distribution.
gov
$\tau_3$ and $\tau_4$ of the Govindarajulu distribution.
ray
$\tau_3$ and $\tau_4$ of the Rayleigh distribution.
lognormal
$\tau_3$ and $\tau_4$ of the Generalized Normal (3-parameter Log-Normal) distribution.
nor
$\tau_3$ and $\tau_4$ of the Normal distribution.
pe3
$\tau_3$ and $\tau_4$ of the Pearson Type III distribution.
rgov
$\tau_3$ and $\tau_4$ of the reversed Govindarajulu.
rgpa
$\tau_3$ and $\tau_4$ of the reversed Generalized Pareto.
slash
$\tau^{(1)}_3$ and $\tau^{(1)}_4$ of the Slash distribution (TL-moment [trim=1]).
uniform
$\tau_3$ and $\tau_4$ of the uniform distribution.
wei
$\tau_3$ and $\tau_4$ of the Weibull distribution (reversed Generalized Extreme Value).

References

Asquith, W.H., 2011, Distributional analysis with L-moment statistics using the R environment for statistical computing: Createspace Independent Publishing Platform, ISBN 978--146350841--8.

Asquith, W.H., 2014, Parameter estimation for the 4-parameter asymmetric exponential power distribution by the method of L-moments using R: Computational Statistics and Data Analysis, v. 71, pp. 955--970.

Hosking, J.R.M., 1986, The theory of probability weighted moments: Research Report RC12210, IBM Research Division, Yorkton Heights, N.Y.

Hosking, J.R.M., 1990, L-moments---Analysis and estimation of distributions using linear combinations of order statistics: Journal of the Royal Statistical Society, Series B, v. 52, pp. 105--124.

Hosking, J.R.M., 1996, FORTRAN routines for use with the method of L-moments: Version 3, IBM Research Report RC20525, T.J. Watson Research Center, Yorktown Heights, New York.

Hosking, J.R.M., and Wallis, J.R., 1997, Regional frequency analysis---An approach based on L-moments: Cambridge University Press.

See Also

plotlmrdia

Examples

Run this code
lratios <- lmrdia()

Run the code above in your browser using DataLab