lmoms. The relations between distribution parameters and L-moments are seen under lmomexp.
parexp(lmom, checklmom=TRUE, ...)lmom be checked for validity using the are.lmom.valid function. Normally this should be left as the default and it is very unlikely that the L-moments will not be viable (particularly in the $\tau_4$ and $\tau_3$ inequality). However, for some circumstances or large simulation exercises then one might want to bypass this check.list is returned.Hosking, J.R.M., 1996, FORTRAN routines for use with the method of L-moments: Version 3, IBM Research Report RC20525, T.J. Watson Research Center, Yorktown Heights, New York.
Hosking, J.R.M., and Wallis, J.R., 1997, Regional frequency analysis---An approach based on L-moments: Cambridge University Press.
lmomexp,
cdfexp, pdfexp, quaexp
lmr <- lmoms(rnorm(20))
parexp(lmr)
Run the code above in your browser using DataLab