Learn R Programming

lmomco (version 2.2.4)

parlmrq: Estimate the Parameters of the Linear Mean Residual Quantile Function Distribution

Description

This function estimates the parameters of the Linear Mean Residual Quantile Function distribution given the L-moments of the data in an L-moment object such as that returned by lmoms. The relations between distribution parameters and L-moments are seen under lmomlmrq.

Usage

parlmrq(lmom, checklmom=TRUE)

Arguments

lmom
An L-moment object created by lmoms or vec2lmom.
checklmom
Should the lmom be checked for validity using the are.lmom.valid function. Normally this should be left as the default.

Value

An R list is returned.
type
The type of distribution: lmrq.
para
The parameters of the distribution.
source
The source of the parameters: “parlmrq”.

References

Midhu, N.N., Sankaran, P.G., and Nair, N.U., 2013, A class of distributions with linear mean residual quantile function and it's generalizations: Statistical Methodology, v. 15, pp. 1--24.

See Also

lmomlmrq, cdflmrq, pdflmrq, qualmrq

Examples

Run this code
lmr <- lmoms(c(3, 0.05, 1.6, 1.37, 0.57, 0.36, 2.2))
parlmrq(lmr)

Run the code above in your browser using DataLab