pwmLC(x, threshold=NULL, nmom=5, sort=TRUE)i=1 of the betas vector.list is returned.
sapply(x, function(v) { if(v >= T) return(T); return(v) } )
to reset the data vector x. By operating on the data in this fashion one can toy with various levels of the threshold for experimental purposes; this seemed a more natural way for general implementation. The code sets $n$ = length(x) and $m$ = n - length(x[x == T]), which also seems natural. The $\beta^A_r$ are computed by dispatching to pwm.
lmoms, pwm2lmom, pwm, pwmRC