list. This function is intended to facilitate the use of L-moments (and TL-moments) that the user might have from other sources. L-moments and L-moment ratios of arbitrary length are supported.Because in typical practice, the $k \ge 3$ order L-moments are dimensionless ratios ($\tau_3$, $\tau_4$, and $\tau_5$), this function computes $\lambda_3$, $\lambda_4$, $\lambda_5$ from $\lambda_2$ from the ratios. However, typical practice is not set on the use of $\lambda_2$ or $\tau$ as measure of dispersion. Therefore, this function takes an lscale optional logical (TRUE|FALSE) argument---if $\lambda_2$ is provided and lscale=TRUE, then $\tau$ is computed by the function and if $\tau$ is provided, then $\lambda_2$ is computed by the function.
vec2lmom(vec, lscale=TRUE, trim=NULL, leftrim=NULL, rightrim=NULL, checklmom=TRUE)TRUE,
the second value in the first argument is $\lambda_2$.NULL if asymmetrical trimming is used.NULL even if trim = 1 if the trimming is symmetrical.NULL even if trim = 1 if the trimming is symmetrical.lmom be checked for validity using the are.lmom.valid function. Normally this should be left as the default unless TL-moments are being constructed in lieu of using vec2TLmom.list is returned.
lmoms, vec2pwmlmr <- vec2lmom(c(12,0.6,0.34,0.20,0.05),lscale=FALSE)
Run the code above in your browser using DataLab