Is the distribution parameter object consistent with the corresponding distribution? The distribution functions (cdfemu, pdfemu, quaemu, lmomemu), and lmomemu require consistent parameters to return the cumulative probability (nonexceedance), density, quantile, and L-moments of the distribution, respectively. These functions internally use the are.paremu.valid function. The documentation for pdfemu provides the conditions for valid parameters.