freq.curve.CCC
functions that compute frequency curves for the L-moments. Frequency curves in hydrologic science is a term typically renaming the more conventional quantile function. The notation
CCC represents the three character notation for the distribution:
exp, gam, gev, gld, glo, gno, gpa,
gum, kap, nor, pe3, and wak. The Cauchy distribution
is not called because of its dependency on trimmed L-moments and its general lack of use in applied
research problems (at least those familiar to the author).freq.curve.all(lmom,aslog10=FALSE,asprob=TRUE,
no2para=FALSE,no3para=FALSE,
no4para=FALSE,no5para=FALSE,
step=FALSE,show=FALSE,
xmin=NULL,xmax=NULL,xlim=NULL,
ymin=NULL,ymax=NULL,ylim=NULL,
exp=TRUE,gam=TRUE,gev=TRUE,gld=FALSE,
glo=TRUE,gno=TRUE,gpa=TRUE,gum=TRUE,
kap=TRUE,nor=TRUE,pe3=TRUE,wak=TRUE,...)lmom.ub or similar.log10 of quantiles--note that NaNs produced in: log(x, base) will be produced for less than zero values.qnorm function is used to convert nonexceedance probabilities, which are produced by nonexceeds, to standard normal deviations. The normal distribution will plot as straight line when thTRUE, do not run the 2-parameter distributions: exp, gam, gum, and nor.TRUE, do not run the 3-parameter distributions: gev, glo, gno, gpa, and pe3.TRUE, do not run the 4-parameter distributions: kap and gld.TRUE, do not run the 5-parameter distributions: wak.plot.show=TRUE.show=TRUE.show=TRUE.show=TRUE.show=TRUE.show=TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.TRUE.parexp.data.frame of frequency curves. The nonexceedance probability values, which are provided by nonexceeds, are the first item in the data.frame under the heading of nonexceeds. If a particular distribution could not be fit to the L-moments of the data; this particular function returns zeros so that a data.frame can be returned.freq.curve.exp,
freq.curve.gam,
freq.curve.gev,
freq.curve.gld,
freq.curve.glo,
freq.curve.gno,
freq.curve.gpa,
freq.curve.gum,
freq.curve.kap,
freq.curve.nor,
freq.curve.pe3, and
freq.curve.wakL <- vec2lmom(c(35612,23593,0.48,0.21,0.11))
freq.curve.all(L,gld=FALSE)
freq.curve.all(L,step=TRUE,no2para=TRUE,no4para=TRUE)Run the code above in your browser using DataLab