lmomRCmark: Sample L-moment for Right-Tail Censoring by a Marking Variable
Description
Compute the sample L-moments for right-tail censored data set in which censored data values are identified by a marking variable.
Usage
lmomRCmark(x, rcmark=NULL, r=1, sort=TRUE)
Arguments
x
A vector of data values.
rcmark
The right-tail censoring (upper) marking variable for unknown threshold: 1 is uncensored, 0 is censored.
r
The L-moment order to return, default is the mean.
sort
Do the data need sorting? The availability of this option is to avoid unnecessary overhead of sorting on each call to this function by the primary higher-level function lmomsRCmark.
Value
An Rlist is returned.
lambdas
Vector of the L-moments. First element is
$\hat{\lambda}^{(0,0)}_1$, second element is $\hat{\lambda}^{(0,0)}_2$, and so on.
ratios
Vector of the L-moment ratios. Second element is
$\hat{\tau}^{(0,0)}$, third element is $\hat{\tau}^{(0,0)}_3$ and so on.
trim
Level of symmetrical trimming used in the computation, which will equal NULL if asymmetrical trimming was used.
leftrim
Level of left-tail trimming used in the computation.
rightrim
Level of right-tail trimming used in the computation.
source
An attribute identifying the computational source of the L-moments: lmomsRCmark.
References
Wang, Dongliang, Hutson, A.D., Miecznikowski, J.C., 2010, L-moment estimation for parametric survival models given censored data: Statistical Methodology, v. 7, no. 6, pp. 655--667.